import { i18n } from '@/i18n'

import {
  isHardMode,
  numberOfGamesSinceStart,
  operations,
  result,
} from './game-state'
import { showToast } from './toast-manager'

function getSharingText(): string {
  const endResult = operations[operations.length - 1].result?.value ?? 0
  const success = result.value === endResult

  // const allSymbols = ['𝙰', '𝙱', '𝙲', '𝙳', '𝙴', '𝙵', '𝚅', '𝚆', '𝚇', '𝚈', '𝚉']
  const abcSymbols = ['𝚊', '𝚋', '𝚌', '𝚍', '𝚎', '𝚏']
  const xyzSymbols = ['𝚟', '𝚠', '𝚡', '𝚢', '𝚣'].slice(-(operations.length - 1))
  // const xyzSymbols = ["𝚊'", "𝚋'", "𝚌'", "𝚍'", "𝚎'", "𝚏'"]
  // const xyzSymbols = ['𝚅', '𝚆', '𝚇', '𝚈', '𝚉']
  const squares = ['🟦', '🟩', '🟨', '🟧', '🟥']

  const lines: string[] = []
  for (const op of operations) {
    op.left!.symbol = op.left!.symbol ?? abcSymbols.shift()
    op.right!.symbol = op.right!.symbol ?? abcSymbols.shift()
    op.result!.symbol = op.result!.symbol ?? xyzSymbols.shift()

    let s = ''
    switch (op.operator) {
      case '*':
        s = '×'
        break
      case '/':
        s = '÷'
        break
      case '-':
        s = '−'
        break
      case '+':
        s = '+'
        break
    }
    lines.push(
      `${squares.shift()} ${op.left?.symbol} ${s} ${op.right?.symbol} = ${
        op.result?.value === endResult ? endResult : op.result?.symbol
      }`,
    )
  }

  return `N0mbers #${numberOfGamesSinceStart()} - ${
    isHardMode.value ? 'Advanced' : 'Normal'
  }
${lines.join('\n')} ${success ? '✔' : '❌'}
https://n0mbers.scambier.xyz`
}

export function toClipboard(): void {
  navigator.clipboard.writeText(getSharingText())
  showToast(i18n.global.t('copiedInClipboard'), 3000)
}
